@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://linterna-magica.nongnu.org
+// @source http://linternamagica.org
 
 // END OF LICENSE HEADER
 
@@ -91,13 +91,13 @@ function LinternaMagica(params)
 
     // Do not change order
     this.check_flash_plugin();
-    this.set_priority(params.priority);
     this.set_autostart(params.autostart);
     this.set_controls(params.controls);
     this.set_cookies(params.cookies);
     this.set_wait_xhr(params.wait_xhr);
     this.set_check_updates(params.updates);
     this.set_hd_link_quality(params.quality);
+    this.set_format(params.format);
 
     // check_for_updates() MUST be called only if there is video object
     // found. The only place where the user can be informed is in the
@@ -189,11 +189,11 @@ LinternaMagica.prototype = new Object ();
 LinternaMagica.constructor = LinternaMagica;
 
 LinternaMagica.prototype.version = "@VERSION@";
-LinternaMagica.prototype.name =  "Linterna Mágica";
+LinternaMagica.prototype.name =  "Linterna M\u00e1gica";
 
 // Release date string in POISIX time format (date +"%s")
 // FIXME: Add real string
-LinternaMagica.prototype.release_date = "1364800275";
+LinternaMagica.prototype.release_date = "1384083414";
 
 // The URL with information about the latest version. Must
 // return JSONP data:
@@ -202,7 +202,7 @@ LinternaMagica.prototype.release_date = "1364800275";
 //    version: <version>,  // string 
 //});
 LinternaMagica.prototype.updates_page =
-    "http://linterna-magica.nongnu.org/downloads/updates.js";
+    "http://linternamagica.org/downloads/updates.js";
 //    "http://localhost/lm/downloads/updates.js";
 
 // When this is a function the internal _() function could be used.
@@ -248,7 +248,7 @@ LinternaMagica.prototype.license_link =
     "https://www.gnu.org/licenses/gpl.html";
 
 LinternaMagica.prototype.homepage = 
-    "http://linterna-magica.nongnu.org";
+    "http://linternamagica.org";
 // "http://localhost/lm";
 
 LinternaMagica.prototype.savannah_page =
@@ -258,7 +258,30 @@ LinternaMagica.prototype.bug_report_link =
     "https://sv.nongnu.org/bugs/?func=additem&amp;group=linterna-magica";
 
 LinternaMagica.prototype.microblog_link =
-    "https://identi.ca/group/linternamagica";
+    "https://identi.ca/valkov";
+   // Identi.ca does not support groups as of pump.io migration.
+   // "https://identi.ca/group/linternamagica";
+
+LinternaMagica.prototype.chat_rooms = function()
+{
+    var rooms = new Array();
+
+    var room = new Object();
+    room.type = "IRC";
+    room.room = "#linternamagica";
+    room.url = "ircs://irc.freenode.net:6697/linternamagica";
+    room.server = "freenode.net";
+    rooms.push(room);
+
+    var room = new Object();
+    room.type = "Jabber/XMPP";
+    room.room = "linternamagica@conference.jabber.org";
+    room.url = "xmpp:linternamagica@conference.jabber.org?join";
+    room.server = "jabber.org";
+    rooms.push(room);
+
+    return rooms;
+};
 
 
 // This is filled during build from the Makefile
