@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://linterna-magica.nongnu.org
+// @source http://linternamagica.org
 
 // END OF LICENSE HEADER
 
@@ -81,6 +81,11 @@ LinternaMagica.prototype.extract_link = function()
 	// significant to be exported in src/lm_site_metacafe.js
 	link = link.replace(/\\\//g, "/");
 
+	// Escape spaces.
+	// See bug #37661
+	// https://savannah.nongnu.org/bugs/index.php?37661
+	link = link.replace(/ /g, "%20");
+
 	var self = this;
 	var val = this.call_site_function_at_position.apply(self,[
 	    "process_extracted_link",
@@ -122,6 +127,21 @@ LinternaMagica.prototype.extract_link = function()
 	//     // 	"mediashare\\\.bg|ted\\\.com",
 	//     "i");
 
+
+	self = this;
+	val = this.call_site_function_at_position.apply(self,[
+	    "skip_flowplayer_links_fix",
+	    window.location.hostname]);
+
+	if (val)
+	{
+	    // Some links used with flowplayer are relative
+	    if (data.match(/.*flowplayer.*/))
+	    {
+		link = this.fix_flowplayer_links(link);
+	    }
+	}
+
 	this.log("LinternaMagica.extract_link:\n"+
 		 " Extracted link: "+link,1);
 
