@@ -3,7 +3,7 @@
 //
 //  This file is part of Linterna Mágica
 //
-//  Copyright (C) 2010, 2011  Ivaylo Valkov <ivaylo@e-valkov.org>
+//  Copyright (C) 2010, 2011, 2012, 2013 Ivaylo Valkov <ivaylo@e-valkov.org>
 //  Copyright (C) 2010  Anton Katsarov <anton@katsarov.org>
 //
 //  The JavaScript code in this page (or file) is free software: you
@@ -23,7 +23,7 @@
 //  @licend The above is the entire license notice for the JavaScript
 //  code in this page (or file).
 //
-// @source http://linterna-magica.nongnu.org
+// @source http://linternamagica.org
 
 // END OF LICENSE HEADER
 
@@ -106,6 +106,7 @@ LinternaMagica.prototype.create_youtube_links = function(fmt, fmt_url_map)
 		break;
 	    case '13':
 	    case '17':
+	    case '36':
 		label += " 3GP";
 		break;
 	    default:
@@ -156,6 +157,7 @@ LinternaMagica.prototype.create_youtube_links = function(fmt, fmt_url_map)
 		break;
 	    case '13':
 	    case '17':
+	    case '36':
 		more_info += "MPEG-4 Visual, AAC";
 		break;
 	    default:
@@ -196,7 +198,7 @@ LinternaMagica.prototype.detect_youtube_flash_upgrade = function(object_data)
 
     // Fancy flash upgrade message. The element with id flash-upgrade
     // might be obsolete now.
-    var watch_player = document.getElementById("watch-player");
+    var watch_player = document.getElementById("watch7-player");
     var fancy_alert = null;
 
     if(watch_player && watch_player.hasAttribute("class") &&
@@ -212,12 +214,13 @@ LinternaMagica.prototype.detect_youtube_flash_upgrade = function(object_data)
     }
     
 
-    // With default timeout 500mS this will be 6 sec. Stop checking and insert.    
+    // With default timeout 3000mS this will be >10 sec. Stop checking and insert.    
     // Might be flashblock
-    if (document.getElementById("flash-upgrade") ||
+    if (document.getElementById("movie_player") ||
+	document.getElementById("movie_player-lm-override") ||
 	document.getElementById("movie_player-html5") ||
 	fancy_alert ||
-	this.youtube_flash_upgrade_counter >= 12 )
+	this.youtube_flash_upgrade_counter >= 5 )
     {
 	clearInterval(this.youtube_flash_upgrade_timeout);
 
@@ -229,7 +232,7 @@ LinternaMagica.prototype.detect_youtube_flash_upgrade = function(object_data)
 	this.log("LinternaMagica.detect_youtube_flash_upgrade:\n"+
 		 "Creating video object.",2);
 
-	this.create_video_object(object_data);
+	setTimeout(this.create_video_object(object_data), 1000);
     }
 }
 
@@ -265,15 +268,27 @@ LinternaMagica.prototype.extract_youtube_fmt_url_map = function()
 	{
 	    // Usually the links have the following pattern
 	    // (itag=fmt_id)*url=URL&type=video/...&(itag=fmt_id)*
-	    var link = fmt[url].match(/url=([^&]+)/);
+	    var link = fmt[url].match(/(url|conn)=([^&]+)/);
 	    var fmt_id = fmt[url].match(/itag=([0-9]+)/);
 	    var sig = fmt[url].replace(/\\u0026/g, '&').match(/sig=[^&]+/);
-		sig = sig[sig.length-1].replace(/sig/,'signature');
+	    sig = sig ? sig[sig.length-1].replace(/sig/,'signature') : '';
+
+	    // Bug 39402. Some links have the signature in the s=<SIG>
+	    // format. For example when they are oppened from Canada
+	    if (!sig)
+	    {
+		this.sites["youtube.com"].encrypted_signature = 1;
+		sig = "";
+	    }
 	    
 	    if (fmt_id && link)
 	    {
 		links++;
 		link = unescape(link[link.length-1]);
+		// Live streams support. 
+		// See bugs #36759:
+		// https://savannah.nongnu.org/bugs/?36759
+		link = link.replace(/\\u0026stream=/, '/');
 		link = link.split(/\\u0026/)[0];
 
 		map[fmt_id[fmt_id.length-1]] =  link+"&"+sig;
@@ -298,7 +313,7 @@ LinternaMagica.prototype.sites["www.youtube.com"] = "youtube.com";
 LinternaMagica.prototype.sites["www.youtube-nocookie.com"] = "youtube.com";
 LinternaMagica.prototype.sites["youtube-nocookie.com"] = "youtube.com";
 
-// Referenced by Vimeo
+// Referenced by Vimeo, Xhamster
 LinternaMagica.prototype.sites["youtube.com"].flash_plugin_installed =
 function()
 {
@@ -334,13 +349,20 @@ LinternaMagica.prototype.sites["youtube.com"].skip_link_extraction = function()
     return false;
 }
 
+LinternaMagica.prototype.sites["youtube.com"].skip_video_id_extraction = function()
+{
+    this.log("LinternaMagica.sites.skip_video_id_extraction:\n"+
+	     "Skipping video_id extraction in YouTube.",4);
+    return false;
+}
+
+
 // Extracts data for the flash object in youtube from a script
 LinternaMagica.prototype.sites["youtube.com"].extract_object_from_script =
 function()
 {
     var data = this.script_data;
-    if (!data.match(/var\s*swfConfig/) &&
-	!data.match(/yt\.setConfig/))
+    if (!data.match(/ytplayer\.config =/))
     {
  	return null;
     }
@@ -379,9 +401,9 @@ function()
 	embed_id= embed_id[embed_id.length-1];
     }
 
-    var p = this.get_first_element_by_class("flash-player");
-    p = p ? p : this.get_first_element_by_class("html5-player");
-
+    var p = document.getElementById("movie_player");
+    p.setAttribute("id", "movie_player-lm-override");
+    p = p.parentNode;
 
     if (!width || !height)
     {
@@ -472,15 +494,113 @@ function(object_data)
 	this.youtube_flash_upgrade_timeout = setInterval(
 	    function() {
 		self.detect_youtube_flash_upgrade.apply(self,[data]);
-	    }, 500);
+	    }, 5000);
     }
     
     return false;
 }
 
+LinternaMagica.prototype.sites["youtube.com"].player_stream_ended_action =
+function()
+{
+    var playlist = document.getElementById("watch7-playlist-tray");
+    var autoplay = document.getElementById("watch7-playlist-bar-autoplay-button");
+    var current_song =
+	this.get_first_element_by_class("playlist-bar-item-playing", playlist);
+
+    var shuffle = document.getElementById("watch7-playlist-bar-shuffle-button");
+
+    var next_song = null;
+
+    if (!playlist || !autoplay || !current_song ||
+	!this.object_has_css_class(autoplay, "yt-uix-button-toggled"))
+    {
+	return;
+    }
+
+    if (shuffle && 
+	this.object_has_css_class(shuffle, "yt-uix-button-toggled"))
+    {
+	var songs = playlist.getElementsByTagName("a");
+	var rand = Math.floor(Math.random() * songs.length);
+	next_song = songs[rand].getAttribute("href");
+    }
+    else 
+    {
+	if (/text/i.test(current_song.nextSibling))
+	{
+	    next_song = current_song.nextSibling.nextSibling;
+	}
+	else
+	{
+	    next_song = current_song.nextSibling;
+	}
+
+	next_song = 
+	    next_song.getElementsByTagName("a")[0].
+	    getAttribute("href");
+    }
+
+    window.location = next_song;
+
+    return true;
+}
+
 LinternaMagica.prototype.sites["youtube.com"].css_fixes =
 function(object_data)
 {
+    // Override YT playlist links, click event. Ensure LM will load
+    // when a new video is selected.
+    var playlist = document.getElementById("watch7-playlist-tray");
+
+    if (playlist)
+    {
+	var links = playlist.getElementsByTagName("a");
+	for (var i=0,l=links.length; i<l;i++)
+	{
+	    var t = links[i];
+	    t.addEventListener('click',
+			       function(ev)
+			       {
+				   window.location = this.href;
+			       },false);
+
+	    t.parentNode.addEventListener('click',
+					  function(ev)
+					  {
+					      window.location =
+						  this.getElementsByTagName('a')[0].
+						  getAttribute('href');
+					  },false);
+	}
+    }
+
+    // Sometimes when flash is installed the flash video object does
+    // not have (at all or the right one) linterna_magica_id. Usually
+    // the other objects if any are useless. This renders both LM and
+    // the flash interface. The code bellow tries to avoid it. Reason
+    // *unknown*.
+
+    this.log("LinternaMagica.youtube.css_fixes:\n "+
+	     "Harvesting (possible) lost flash video object with "+
+	     "linterna_magica_id "+ object_data.linterna_magica_id);
+
+    var movie_player = document.getElementById('movie_player-lm-override');
+
+    if (movie_player) {
+	movie_player.linterna_magica_id = object_data.linterna_magica_id;
+    }
+
+    // Remove flash object
+    var embed = document.getElementById('movie_player');
+
+    if (embed && this.is_swf_object(embed))
+    {
+	embed.parentNode.removeChild(embed);
+    }
+
+    this.hide_flash_video_object(object_data.linterna_magica_id);
+
     if (document.getElementById("playnav-playview"))
     {
 	// In channels/user pages in YouTube the web controlls are
@@ -552,30 +672,6 @@ function(object_data)
 	
     }
 
-    // Sometimes the toggle plugin button that should be bellow the
-    // HTML5/Flash player shows on top. The following tries to fix
-    // this.  Most of the time the bug occurs in Epiphany.s
-
-    var id = object_data.linterna_magica_id;
-    var toggle_plugin = document.getElementById("linterna-magica-toggle-plugin-"+id);
-    
-    if (toggle_plugin)
-    {
-	var lm = document.getElementById("linterna-magica-"+id);
-	var h_lm = parseInt(lm.style.getPropertyValue("height"));
-
-	toggle_plugin = toggle_plugin.parentNode;
-	var display = toggle_plugin.style.getPropertyValue("display");
-	var top = toggle_plugin.offsetTop;
-
-	if (!display && !top)
-	{
-	    toggle_plugin.style.setProperty("top", 
-					    (h_lm +30)+"px",
-					    "important");
-	}
-    }
-
     // When YouTube's HTML5 player detects that the browser does not
     // have support for any clip, a warning div is displayed. It must
     // be hidden or it displaces Linterna Magica.
@@ -607,42 +703,7 @@ function(object_data)
 	    // will not be displaced.
 	    html5_wrapper.style.setProperty('display', "none", "important");
 
-	    // If the HTML5 player has a fallback CSS class and LM can
-	    // access it it means there is no other option for
-	    // playback. We take over the player.
-	    //
-	    // See bug 37630
-	    // https://savannah.nongnu.org/bugs/index.php?37630
-	    if (this.priority.html5 > this.priority.self)
- 	    {
-		// It should be available, because it is used above in
-		// this function
-		id = id ? id : object_data.linterna_magica_id;
-
-		var lm = document.getElementById("linterna-magica-"+id);
-
-		if (!lm)
-		{
-		    return null;
-		}
-
-		lm.style.removeProperty("display");
-	    
-		// It should be available, because it is used above in
-		// this functon.
-		toggle_plugin = toggle_plugin  ? toggle_plugin :
-		    document.getElementById("linterna-magica-"+
-					    "toggle-plugin-"+id);
-
-		toggle_plugin.parentNode.removeChild(toggle_plugin);
-
-		toggle_plugin_header =
-		    document.getElementById("linterna-magica-"+
-					    "toggle-plugin-header-"+id);
-		
-		toggle_plugin_header.parentNode.removeChild(toggle_plugin_header);
-	    }
-	    
+    
 	    // Hide site controls and video container. Should not
 	    // overlap with Linterna Magica now. Fixes the overlapping
 	    // of HTML5 player and LM.
@@ -662,43 +723,24 @@ function(object_data)
 	}
     }
 
+    // Without this the toggle plugin stays hidden below the title of
+    // the clip
+    var watch7 = document.getElementById('watch7-player');
+    if (watch7)
+    {
+	watch7.style.setProperty("height", 
+				 (parseInt(object_data.outer_height)+
+				  24)+"px", "important");
+
+	var movie_player = document.getElementById("movie_player-lm-override");
+	if (movie_player)
+	{
+	    movie_player.style.setProperty("height", 
+					   parseInt(object_data.outer_height)+
+					   "px", "important");
+	}
+    }
+
     return false;
 }
 
-// Fixes the overlapping of the HD links list in YouTube's new design
-// See bug #37881
-// http://savannah.nongnu.org/bugs/?37881
-LinternaMagica.prototype.sites["youtube.com"].post_show_hd_links_list =
-function()
-{
-    var play_list= document.getElementById("watch7-playlist-tray-container");
-    if (play_list)
-    {
-	play_list.style.setProperty("display", "none", "important");
-    }
-
-    var side_bar= document.getElementById("watch7-sidebar");
-    if (side_bar)
-    {
-	side_bar.style.setProperty("display", "none", "important");
-    }
-}
-
-// Fixes the overlapping of the HD links list in YouTube's new design
-// See bug #37881
-// http://savannah.nongnu.org/bugs/?37881
-LinternaMagica.prototype.sites["youtube.com"].post_hide_hd_links_list =
-function()
-{
-    var play_list= document.getElementById("watch7-playlist-tray-container");
-    if (play_list)
-    {
-	play_list.style.removeProperty("display");
-    }
-
-    var side_bar= document.getElementById("watch7-sidebar");
-    if (side_bar)
-    {
-	side_bar.style.removeProperty("display");
-    }
-}
